Bootstrap Components › Modal — Stisla

# Modal

Use Bootstrap’s JavaScript modal plugin to add dialogs to your site for lightboxes, user notifications, or completely custom content.

##### Modal Template

Modal body text goes here.

#### Modal Confirm

You can easily change the default browser confirmation box with a bootstrap modal.

#### The Bootstrap Way

Use the Bootstrap method to create modal. You need to create an HTML structure for modal and the following button will trigger it.

#### Modal Demo

We've created a plugin to easily create a bootstrap modal.

#### Modal Center

You can change the modal position to center.

#### The Others

Check the `modal.js` code in the `dist/js/page` folder to get the source code.

This login form is taken from elements with `#modal-login-part` id.

Username
Password
Remember Me

##### Modal title

Modal body text goes here.